visioglobe_flutter_plugin library

Classes

CameraContext
Dart representation of the camera context.
GuidanceState
The current state of active route guidance.
MapTheme
Custom map & route theme configuration.
MarkerOptions
Options for configuring a custom marker placed on the map.
PlaceInfo
Represents detailed information about a place (POI) on the map.
PoiSize
Marker sizing configuration.
RouteLocation
A location waypoint used in route calculations.
RouteRequest
Request parameters for calculating a route.
RouteResult
The result of a successful route calculation.
RouteSegment
A specific path segment in a calculated route.
SceneContext
Dart representation of the scene context.
UserLocation
Dart representation of the user location.
VisioglobeController
Controller for a VisioglobeMap.
VisioglobeMap
A widget that embeds a Visioglobe indoor map. A Flutter widget that embeds the Visioglobe map.

Enums

AccessibilityMode
Mode of accessibility for the route.
AnchorMode
Alignment anchor modes for map markers.
LocationTrackingMode
Dart representation of the location tracking mode.
MapLifecycleEvent
Lifecycle events emitted by the map.
Mode of navigation for the camera.
ViewMode
Dart representation of ViewMode.

Exceptions / Errors

MapDataNotReadyException
Exception thrown when Place data is requested before the Venue data loads.
MapNotReadyException
Exception thrown when interacting with the map before it is fully loaded. Exception thrown when an operation is performed before the map is fully loaded.
PlaceException
Exception thrown for place-related errors.
RouteException
Exception thrown when a route could not be computed. Exception thrown when a routing operation fails.
VisioglobeException
Exceptions thrown by the Visioglobe map. The base exception class for all Visioglobe-related errors.