GuidanceState class

The current state of active route guidance.

Constructors

GuidanceState({required String currentInstruction, required double distanceToNextManeuver, required String nextManeuverType, required bool reachedDestination})
Creates a guidance state update.
GuidanceState.fromMessage(GuidanceStateMessage message)
factory

Properties

currentInstruction String
The text instruction to display to the user.
final
distanceToNextManeuver double
The distance in meters to the next maneuver.
final
hashCode int
The hash code for this object.
no setterinherited
nextManeuverType String
The type of maneuver coming up next.
final
reachedDestination bool
True if the user has reached the final destination.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited