RouteLocation class

A location waypoint used in route calculations.

Constructors

RouteLocation({double? lat, double? lng, double? alt, String? placeId, String? buildingId, String? floorId})
Creates a route location. Requires either a placeId or both lat/lng.
RouteLocation.fromMessage(RouteLocationMessage message)
factory

Properties

alt double?
Optional altitude.
final
buildingId String?
Optional building identifier.
final
floorId String?
Optional floor identifier.
final
hashCode int
The hash code for this object.
no setterinherited
lat double?
Optional latitude.
final
lng double?
Optional longitude.
final
placeId String?
Optional place identifier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMessage() → RouteLocationMessage
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited